@@ -1,7 +1,7 @@
-package Search::Elasticsearch::Client::5_0::Direct::Cat;
-$Search::Elasticsearch::Client::5_0::Direct::Cat::VERSION = '5.00';
+package Search::Elasticsearch::Client::6_0::Direct::Cat;
+$Search::Elasticsearch::Client::6_0::Direct::Cat::VERSION = '6.00';
 use Moo;
-with 'Search::Elasticsearch::Client::5_0::Role::API';
+with 'Search::Elasticsearch::Client::6_0::Role::API';
 with 'Search::Elasticsearch::Role::Client::Direct';
 use Search::Elasticsearch::Util qw(parse_params);
 use namespace::clean;
@@ -38,11 +38,11 @@ around 'perform_request' => sub {
 
 =head1 NAME
 
-Search::Elasticsearch::Client::5_0::Direct::Cat - A client for running cat debugging requests
+Search::Elasticsearch::Client::6_0::Direct::Cat - A client for running cat debugging requests
 
 =head1 VERSION
 
-version 5.00
+version 6.00
 
 =head1 DESCRIPTION
 
@@ -99,11 +99,14 @@ Returns information about index aliases, optionally limited to the specified
 index/alias names.
 
 Query string parameters:
+    C<error_trace>,
     C<format>,
     C<h>,
     C<help>,
+    C<human>,
     C<local>,
     C<master_timeout>,
+    C<s>,
     C<v>
 
 See the L<cat aliases docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/cat-aliases.html>
@@ -120,11 +123,14 @@ state of disk usage.
 
 Query string parameters:
     C<bytes>,
+    C<error_trace>,
     C<format>,
     C<h>,
     C<help>,
+    C<human>,
     C<local>,
     C<master_timeout>,
+    C<s>,
     C<v>
 
 See the L<cat allocation docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/cat-allocation.html>
@@ -140,11 +146,14 @@ Provides quick access to the document count of the entire cluster, or
 individual indices.
 
 Query string parameters:
+    C<error_trace>,
     C<format>,
     C<h>,
     C<help>,
+    C<human>,
     C<local>,
     C<master_timeout>,
+    C<s>,
     C<v>
 
 See the L<cat count docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/cat-count.html>
@@ -161,11 +170,14 @@ fields) loaded into fielddata.
 
 Query string parameters:
     C<bytes>,
+    C<error_trace>,
     C<format>,
     C<h>,
     C<help>,
+    C<human>,
     C<local>,
     C<master_timeout>,
+    C<s>,
     C<v>
 
 See the L<cat fielddata docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/cat-fielddata.html>
@@ -179,12 +191,15 @@ Provides a snapshot of how shards have located around the cluster and the
 state of disk usage.
 
 Query string parameters:
+    C<error_trace>,
     C<format>,
     C<h>,
     C<help>,
+    C<human>,
     C<local>,
     C<master_timeout>,
     C<ts>,
+    C<s>,
     C<v>
 
 See the L<cat health docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/cat-health.html>
@@ -201,13 +216,16 @@ or individual indices
 
 Query string parameters:
     C<bytes>,
+    C<error_trace>,
     C<format>,
     C<h>,
     C<health>,
     C<help>,
+    C<human>,
     C<local>,
     C<master_timeout>,
     C<pri>,
+    C<s>,
     C<v>
 
 See the L<cat indices docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/cat-indices.html>
@@ -220,11 +238,14 @@ for more information.
 Displays the master’s node ID, bound IP address, and node name.
 
 Query string parameters:
+    C<error_trace>,
     C<format>,
     C<h>,
     C<help>,
+    C<human>,
     C<local>,
     C<master_timeout>,
+    C<s>,
     C<v>
 
 See the L<cat master docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/cat-master.html>
@@ -237,11 +258,14 @@ for more information.
 Returns the node attributes set per node.
 
 Query string parameters:
+    C<error_trace>,
     C<format>,
     C<h>,
     C<help>,
+    C<human>,
     C<local>,
     C<master_timeout>,
+    C<s>,
     C<v>
 
 See the L<cat nodeattrs docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/cat-nodeattrs.html>
@@ -254,11 +278,14 @@ for more information.
 Provides a snapshot of all of the nodes in your cluster.
 
 Query string parameters:
+    C<error_trace>,
     C<format>,
     C<h>,
     C<help>,
+    C<human>,
     C<local>,
     C<master_timeout>,
+    C<s>,
     C<v>
 
 See the L<cat nodes docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/cat-nodes.html>
@@ -271,11 +298,14 @@ for more information.
 Returns any cluster-level tasks which are queued on the master.
 
 Query string parameters:
+    C<error_trace>,
     C<format>,
+    C<human>,
     C<local>,
     C<master_timeout>,
     C<h>,
     C<help>,
+    C<s>,
     C<v>
 
 See the L<cat pending-tasks docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/cat-pending-tasks.html>
@@ -288,11 +318,14 @@ for more information.
 Returns information about plugins installed on each node.
 
 Query string parameters:
+    C<error_trace>,
     C<format>,
+    C<human>,
     C<local>,
     C<master_timeout>,
     C<h>,
     C<help>,
+    C<s>,
     C<v>
 
 See the L<cat plugins docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/cat-plugins.html>
@@ -311,10 +344,13 @@ stuck, try it to see if there’s any movement using C<recovery()>.
 
 Query string parameters:
     C<bytes>,
+    C<error_trace>,
     C<format>,
     C<h>,
     C<help>,
+    C<human>,
     C<master_timeout>,
+    C<s>,
     C<v>
 
 See the L<cat recovery docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/cat-recovery.html>
@@ -327,11 +363,14 @@ for more information.
 Provides a list of registered snapshot repositories.
 
 Query string parameters:
+    C<error_trace>,
     C<format>,
     C<h>,
     C<help>,
+    C<human>,
     C<local>,
     C<master_timeout>,
+    C<s>,
     C<v>
 
 See the L<cat repositories docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/cat-repositories.html>
@@ -346,9 +385,13 @@ for more information.
 Provides low level information about the segments in the shards of an index.
 
 Query string parameters:
+    C<bytes>,
+    C<error_trace>,
     C<format>,
     C<h>,
     C<help>,
+    C<human>,
+    C<s>,
     C<v>
 
 See the L<cat shards docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/cat-segments.html>
@@ -364,11 +407,15 @@ Provides a detailed view of what nodes contain which shards, the state and
 size of each shard.
 
 Query string parameters:
+    C<bytes>,
+    C<error_trace>,
     C<format>,
     C<h>,
     C<help>,
+    C<human>,
     C<local>,
     C<master_timeout>,
+    C<s>,
     C<v>
 
 See the L<cat shards docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/cat-shards.html>
@@ -377,17 +424,20 @@ for more information.
 =head2 C<snapshots()>
 
     say $e->cat->snapshots(
-        repository => 'repository' | \@repositories # required
+        repository => 'repository' | \@repositories # optional
     )
 
 Provides a list of all snapshots that belong to the specified repositories.
 
 Query string parameters:
+    C<error_trace>,
     C<format>,
     C<h>,
     C<help>,
+    C<human>,
     C<ignore_unavailable>,
     C<master_timeout>,
+    C<s>,
     C<v>
 
 See the L<cat snapshots docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/cat-snapshots.html>
@@ -402,17 +452,42 @@ Provides a list of node-level tasks.
 Query string parameters:
     C<actions>,
     C<detailed>,
+    C<error_trace>,
     C<format>,
     C<h>,
     C<help>,
+    C<human>,
     C<node_id>,
     C<parent_node>,
     C<parent_task>,
+    C<s>,
     C<v>
 
 See the L<cat tasks docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/tasks.html>
 for more information.
 
+=head2 C<templates()>
+
+    say $e->cat->templates(
+        name => $name # optional
+    )
+
+Provides a list of index templates.
+
+Query string parameters:
+    C<error_trace>,
+    C<format>,
+    C<h>,
+    C<help>,
+    C<human>,
+    C<local>,
+    C<master_timeout>,
+    C<s>,
+    C<v>
+
+See the L<cat templates docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/templates.html>
+for more information.
+
 =head2 C<thread_pool()>
 
     say $e->cat->thread_pool(
@@ -424,13 +499,15 @@ C<queue> and C<rejected> statistics are returned for the C<bulk>, C<index> and
 C<search> thread pools.
 
 Query string parameters:
+    C<error_trace>,
     C<format>,
     C<h>,
     C<help>,
+    C<human>,
     C<local>,
     C<master_timeout>,
     C<size>,
-    C<thread_pool_patterns>,
+    C<s>,
     C<v>
 
 See the L<cat thread_pool docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/cat-thread-pool.html>
@@ -442,7 +519,7 @@ Clinton Gormley <drtech@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Elasticsearch BV.
+This software is Copyright (c) 2017 by Elasticsearch BV.
 
 This is free software, licensed under:
 
