@@ -1,7 +1,7 @@
-package Search::Elasticsearch::Client::5_0::Direct::Indices;
-$Search::Elasticsearch::Client::5_0::Direct::Indices::VERSION = '5.01';
+package Search::Elasticsearch::Client::6_0::Direct::Indices;
+$Search::Elasticsearch::Client::6_0::Direct::Indices::VERSION = '6.00';
 use Moo;
-with 'Search::Elasticsearch::Client::5_0::Role::API';
+with 'Search::Elasticsearch::Client::6_0::Role::API';
 with 'Search::Elasticsearch::Role::Client::Direct';
 __PACKAGE__->_install_api('indices');
 
@@ -13,11 +13,11 @@ __PACKAGE__->_install_api('indices');
 
 =head1 NAME
 
-Search::Elasticsearch::Client::5_0::Direct::Indices - A client for running index-level requests
+Search::Elasticsearch::Client::6_0::Direct::Indices - A client for running index-level requests
 
 =head1 VERSION
 
-version 5.01
+version 6.00
 
 =head1 DESCRIPTION
 
@@ -45,6 +45,8 @@ The C<create()> method is used to create an index. Optionally, index
 settings, type mappings, and aliases can be added at the same time.
 
 Query string parameters:
+    C<error_trace>,
+    C<human>,
     C<master_timeout>,
     C<timeout>,
     C<update_all_types>,
@@ -56,19 +58,18 @@ for more information.
 =head2 C<get()>
 
     $response = $e->indices->get(
-        index   => 'index'   | \@indices    # optional
-        feature => 'feature' | \@features   # optional
+        index   => 'index'   | \@indices    # required
     );
 
-Returns the aliases, settings, and mappingsfor the specified indices.
-The C<feature> parameter can be set to none or more of: C<_settings>, C<_mappings>,
-and C<_aliases>.
+Returns the aliases, settings, and mappings for the specified indices.
 
 See the L<get index docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-get-index.html>.
 
 Query string parameters:
     C<allow_no_indices>,
+    C<error_trace>,
     C<expand_wildcards>,
+    C<flat_settings>,
     C<human>,
     C<ignore_unavailable>,
     C<include_defaults>,
@@ -85,8 +86,12 @@ whether the specified index or indices exist.
 
 Query string parameters:
     C<allow_no_indices>,
+    C<error_trace>,
     C<expand_wildcards>,
+    C<flat_settings>,
+    C<human>,
     C<ignore_unavailable>,
+    C<include_defaults>,
     C<local>
 
 See the L<index exists docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-indices-exists.html>
@@ -102,7 +107,9 @@ The C<delete()> method deletes the specified indices.
 
 Query string parameters:
     C<allow_no_indices>,
+    C<error_trace>,
     C<expand_wildcards>,
+    C<human>,
     C<ignore_unavailable>,
     C<master_timeout>,
     C<timeout>
@@ -121,7 +128,9 @@ but allowing them to be reopened later.
 
 Query string parameters:
     C<allow_no_indices>,
+    C<error_trace>,
     C<expand_wildcards>,
+    C<human>,
     C<ignore_unavailable>
     C<master_timeout>,
     C<timeout>
@@ -139,7 +148,9 @@ The C<open()> method opens closed indices.
 
 Query string parameters:
     C<allow_no_indices>,
+    C<error_trace>,
     C<expand_wildcards>,
+    C<human>,
     C<ignore_unavailable>
     C<master_timeout>,
     C<timeout>
@@ -159,6 +170,9 @@ Rollover an index pointed to by C<alias> if it meets rollover conditions
 (eg max age, max docs) to a new index name.
 
 Query string parameters:
+    C<dry_run>,
+    C<error_trace>,
+    C<human>,
     C<master_timeout>,
     C<timeout>,
     C<wait_for_active_shards>
@@ -178,6 +192,8 @@ The shrink API shrinks the shards of an index down to a single shard (or to a fa
 of the original shards).
 
 Query string parameters:
+    C<error_trace>,
+    C<human>,
     C<master_timeout>,
     C<timeout>,
     C<wait_for_active_shards>
@@ -196,9 +212,11 @@ or id cache for the specified indices.
 
 Query string parameters:
     C<allow_no_indices>,
+    C<error_trace>,
     C<expand_wildcards>,
     C<fielddata>,
     C<fields>,
+    C<human>,
     C<ignore_unavailable>,
     C<query>,
     C<recycler>,
@@ -219,8 +237,9 @@ happens automatically once every second by default.
 
 Query string parameters:
     C<allow_no_indices>,
+    C<error_trace>,
     C<expand_wildcards>,
-    C<force>,
+    C<human>,
     C<ignore_unavailable>
 
 See the L<refresh index docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-refresh.html>
@@ -238,8 +257,10 @@ This process normally happens automatically.
 
 Query string parameters:
     C<allow_no_indices>,
+    C<error_trace>,
     C<expand_wildcards>,
     C<force>,
+    C<human>,
     C<ignore_unavailable>,
     C<wait_if_ongoing>
 
@@ -268,7 +289,9 @@ for more information.
 
 Query string parameters:
     C<allow_no_indices>,
+    C<error_trace>,
     C<expand_wildcards>,
+    C<human>,
     C<ignore_unavailable>
 
 =head2 C<forcemerge()>
@@ -283,8 +306,10 @@ with care, and only on indices that are no longer being updated.
 
 Query string parameters:
     C<allow_no_indices>,
+    C<error_trace>,
     C<expand_wildcards>,
     C<flush>,
+    C<human>,
     C<ignore_unavailable>,
     C<max_num_segments>,
     C<only_expunge_deletes>,
@@ -304,6 +329,7 @@ upgraded, which can be done with the C<upgrade()> method.
 
 Query string parameters:
     C<allow_no_indices>,
+    C<error_trace>,
     C<expand_wildcards>,
     C<human>,
     C<ignore_unavailable>
@@ -321,7 +347,9 @@ The C<upgrade()> method upgrades all segments in the specified indices to the la
 
 Query string parameters:
     C<allow_no_indices>,
+    C<error_trace>,
     C<expand_wildcards>,
+    C<human>,
     C<ignore_unavailable>,
     C<only_ancient_segments>,
     C<wait_for_completion>
@@ -361,7 +389,9 @@ For instance:
 
 Query string parameters:
     C<allow_no_indices>,
+    C<error_trace>,
     C<expand_wildcards>,
+    C<human>,
     C<ignore_unavailable>,
     C<master_timeout>,
     C<timeout>,
@@ -382,7 +412,9 @@ all types in one, more or all indices.
 
 Query string parameters:
     C<allow_no_indices>,
+    C<error_trace>,
     C<expand_wildcards>,
+    C<human>,
     C<ignore_unavailable>,
     C<local>
 
@@ -404,7 +436,9 @@ all fields in one, more or all types and indices.
 
 Query string parameters:
     C<allow_no_indices>,
+    C<error_trace>,
     C<expand_wildcards>,
+    C<human>,
     C<ignore_unavailable>,
     C<include_defaults>,
     C<local>
@@ -424,7 +458,9 @@ in all specified indices, and returns C<1> or the empty string.
 
 Query string parameters:
     C<allow_no_indices>,
+    C<error_trace>,
     C<expand_wildcards>,
+    C<human>,
     C<ignore_unavailable>,
     C<local>
 
@@ -452,6 +488,8 @@ index aliases atomically. For instance:
     );
 
 Query string parameters:
+    C<error_trace>,
+    C<human>,
     C<master_timeout>,
     C<timeout>
 
@@ -478,6 +516,8 @@ The C<put_alias()> method creates an index alias. For instance:
     );
 
 Query string parameters:
+    C<error_trace>,
+    C<human>,
     C<master_timeout>,
     C<timeout>
 
@@ -496,7 +536,9 @@ aliases in the specified indices.
 
 Query string parameters:
     C<allow_no_indices>,
+    C<error_trace>,
     C<expand_wildcards>,
+    C<human>,
     C<ignore_unavailable>,
     C<local>
 
@@ -515,7 +557,9 @@ whether the specified aliases exist in the specified indices.
 
 Query string parameters:
     C<allow_no_indices>,
+    C<error_trace>,
     C<expand_wildcards>,
+    C<human>,
     C<ignore_unavailable>,
     C<local>
 
@@ -533,6 +577,8 @@ The C<delete_alias()> method deletes one or more aliases from one or more
 indices.
 
 Query string parameters:
+    C<error_trace>,
+    C<human>,
     C<master_timeout>,
     C<timeout>
 
@@ -560,8 +606,10 @@ indices or all indices. For instance:
 
 Query string parameters:
     C<allow_no_indices>,
+    C<error_trace>,
     C<expand_wildcards>,
     C<flat_settings>,
+    C<human>,
     C<ignore_unavailable>,
     C<master_timeout>,
     C<preserve_existing>
@@ -581,6 +629,7 @@ indices or all indices.
 
 Query string parameters:
     C<allow_no_indices>,
+    C<error_trace>,
     C<expand_wildcards>,
     C<flat_settings>,
     C<human>,
@@ -604,7 +653,9 @@ The C<put_template()> method is used to create or update index templates.
 
 Query string parameters:
     C<create>,
+    C<error_trace>,
     C<flat_settings>,
+    C<human>,
     C<master_timeout>,
     C<op_type>,
     C<order>,
@@ -624,7 +675,9 @@ for more information.
 The C<get_template()> method is used to retrieve a named template.
 
 Query string parameters:
+    C<error_trace>,
     C<flat_settings>,
+    C<human>,
     C<local>,
     C<master_timeout>
 
@@ -634,12 +687,15 @@ for more information.
 =head2 C<exists_template()>
 
     $result = $e->indices->exists_template(
-        name  => 'template'                 # required
+        name  => 'template'                 # optional
     );
 
 The C<exists_template()> method is used to check whether the named template exists.
 
 Query string parameters:
+    C<error_trace>,
+    C<flat_settings>,
+    C<human>,
     C<local>,
     C<master_timeout>
 
@@ -655,6 +711,8 @@ for more information.
 The C<delete_template()> method is used to delete a named template.
 
 Query string parameters:
+    C<error_trace>,
+    C<human>,
     C<master_timeout>,
     C<timeout>,
     C<version>,
@@ -697,10 +755,12 @@ Allowed metrics are:
 
 Query string parameters:
     C<completion_fields>,
+    C<error_trace>,
     C<fielddata_fields>,
     C<fields>,
     C<groups>,
     C<human>,
+    C<include_segment_file_sizes>,
     C<level>,
     C<types>
 
@@ -718,6 +778,7 @@ Provides insight into on-going shard recoveries.
 Query string parameters:
     C<active_only>,
     C<detailed>,
+    C<error_trace>,
     C<human>
 
 See the L<recovery docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-recovery.html>
@@ -734,6 +795,7 @@ that an index contains.
 
 Query string parameters:
     C<allow_no_indices>,
+    C<error_trace>,
     C<expand_wildcards>,
     C<human>,
     C<ignore_unavailable>,
@@ -753,6 +815,7 @@ copies of which shards, whether the shards are allocated or not.
 
 Query string parameters:
     C<allow_no_indices>,
+    C<error_trace>,
     C<expand_wildcards>,
     C<human>,
     C<ignore_unavailable>,
@@ -776,16 +839,9 @@ with a particular index or field - and returns the tokens.  Very useful
 for debugging analyzer configurations.
 
 Query string parameters:
-    C<analyzer>,
-    C<attributes>,
-    C<char_filter>,
-    C<explain>,
-    C<field>,
-    C<filter>,
+    C<error_trace>,
     C<format>,
-    C<prefer_local>,
-    C<text>,
-    C<tokenizer>
+    C<prefer_local>
 
 See the L<analyze docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-analyze.html>
 for more information.
@@ -804,16 +860,17 @@ whether the query is valid or not.  Most useful when C<explain> is set
 to C<true>, in which case it includes an execution plan in the output.
 
 Query string parameters:
+    C<all_shards>,
     C<allow_no_indices>,
     C<analyze_wildcard>,
     C<analyzer>,
     C<default_operator>,
     C<df>,
+    C<error_trace>,
     C<explain>,
     C<expand_wildcards>,
     C<ignore_unavailable>,
     C<lenient>,
-    C<lowercase_expanded_terms>
     C<q>,
     C<rewrite>
 
@@ -826,7 +883,7 @@ Clinton Gormley <drtech@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Elasticsearch BV.
+This software is Copyright (c) 2017 by Elasticsearch BV.
 
 This is free software, licensed under:
 
