@@ -1,7 +1,7 @@
-package Search::Elasticsearch::Client::5_0::Direct::Nodes;
-$Search::Elasticsearch::Client::5_0::Direct::Nodes::VERSION = '5.00';
+package Search::Elasticsearch::Client::6_0::Direct::Nodes;
+$Search::Elasticsearch::Client::6_0::Direct::Nodes::VERSION = '6.00';
 use Moo;
-with 'Search::Elasticsearch::Client::5_0::Role::API';
+with 'Search::Elasticsearch::Client::6_0::Role::API';
 with 'Search::Elasticsearch::Role::Client::Direct';
 __PACKAGE__->_install_api('nodes');
 
@@ -13,11 +13,11 @@ __PACKAGE__->_install_api('nodes');
 
 =head1 NAME
 
-Search::Elasticsearch::Client::5_0::Direct::Nodes - A client for running node-level requests
+Search::Elasticsearch::Client::6_0::Direct::Nodes - A client for running node-level requests
 
 =head1 VERSION
 
-version 5.00
+version 6.00
 
 =head1 DESCRIPTION
 
@@ -52,6 +52,7 @@ Allowed metrics are:
     C<transport>
 
 Query string parameters:
+    C<error_trace>,
     C<flat_settings>,
     C<human>
 
@@ -79,6 +80,7 @@ Allowed metrics are:
     C<breaker>,
     C<fs>,
     C<http>,
+    C<include_segment_file_sizes>,
     C<indices>,
     C<jvm>,
     C<network>,
@@ -89,11 +91,11 @@ Allowed metrics are:
     C<transport>
 
 If the C<indices> metric (or C<_all>) is specified, then
-L<indices_stats|Search::Elasticsearch::Client::5_0::Direct::Indices/indices_stats()>
+L<indices_stats|Search::Elasticsearch::Client::6_0::Direct::Indices/indices_stats()>
 information is returned on a per-node basis. Which indices stats are
 returned can be controlled with the C<index_metric> parameter:
 
-    $response = $e->cluster->node_stats(
+    $response = $e->nodes->stats(
         node_id       => 'node_1',
         metric        => ['indices','fs']
         index_metric  => ['docs','fielddata']
@@ -120,6 +122,7 @@ Allowed index metrics are:
 
 Query string parameters:
     C<completion_fields>,
+    C<error_trace>,
     C<fielddata_fields>,
     C<fields>,
     C<groups>,
@@ -127,7 +130,7 @@ Query string parameters:
     C<level>,
     C<types>
 
-See the L<node_stats docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/cluster-nodes-stats.html>
+See the L<stats docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/cluster-nodes-stats.html>
 for more information.
 
 =head2 C<hot_threads()>
@@ -140,6 +143,8 @@ The C<hot_threads()> method is a useful tool for diagnosing busy nodes. It
 takes a snapshot of which threads are consuming the most CPU.
 
 Query string parameters:
+    C<error_trace>,
+    C<human>,
     C<ignore_idle_threads>,
     C<interval>,
     C<snapshots>,
@@ -150,13 +155,30 @@ Query string parameters:
 See the L<hot_threads docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/cluster-nodes-hot-threads.html>
 for more information.
 
+=head2 C<usage()>
+
+    $response = $e->nodes->usage(
+        node_id => $node_id | \@node_ids       # optional
+        metric  => $metric  | \@metrics        # optional
+    )
+
+The C<usage()> API retrieve sinformation on the usage of features for each node.
+
+Query string parameters:
+    C<error_trace>,
+    C<human>,
+    C<timeout>
+
+See the L<nodes_usage docs|https://www.elastic.co/guide/en/elasticsearch/reference/current/cluster-nodes-usage.html>
+for more information.
+
 =head1 AUTHOR
 
 Clinton Gormley <drtech@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Elasticsearch BV.
+This software is Copyright (c) 2017 by Elasticsearch BV.
 
 This is free software, licensed under:
 
