@@ -1,5 +1,5 @@
 package Search::Elasticsearch::Role::Cxn;
-$Search::Elasticsearch::Role::Cxn::VERSION = '5.01';
+$Search::Elasticsearch::Role::Cxn::VERSION = '6.00';
 use Moo::Role;
 use Search::Elasticsearch::Util qw(parse_params throw to_list);
 use List::Util qw(min);
@@ -47,6 +47,7 @@ my %Code_To_Error = (
     404 => 'Missing',
     408 => 'RequestTimeout',
     409 => 'Conflict',
+    413 => 'ContentLength',
     502 => 'BadGateway',
     503 => 'Unavailable',
     504 => 'GatewayTimeout'
@@ -302,9 +303,11 @@ sub process_response {
     my $is_encoded = $mime_type && $mime_type ne 'text/plain';
 
     # Deprecation warnings
-    if (my $warnings = $headers->{warning}) {
-        $warnings = join ("; ",@$warnings) if ref $warnings eq 'ARRAY';
-        $self->logger->deprecation($warnings,$params);
+    if ( my $warnings = $headers->{warning} ) {
+        my $warning_string = _parse_warnings($warnings);
+        my %temp = (%$params);
+        delete $temp{data};
+        $self->logger->deprecation( $warning_string, \%temp );
     }
 
     # Request is successful
@@ -345,8 +348,7 @@ sub process_response {
 
         $error_args{current_version} = $1
             if $error_type eq 'Conflict'
-            and $msg
-            =~ /: version conflict, current (?:version )?\[(\d+)\]/;
+            and $msg =~ /: version conflict, current (?:version )?\[(\d+)\]/;
     }
     $msg ||= $error_type;
 
@@ -355,6 +357,24 @@ sub process_response {
         \%error_args );
 }
 
+#===================================
+sub _parse_warnings {
+#===================================
+    my @warnings = ref $_[0] eq 'ARRAY' ? @{ shift() } : shift();
+    my @str;
+    for (@warnings) {
+        if ( $_ =~ /^\d+\s+\S+\s+"((?:\\"|[^"])+)"/ ) {
+            my $msg = $1;
+            $msg=~s/\\"/"/g,
+            push @str, $msg;
+        }
+        else {
+            push @str, $_;
+        }
+    }
+    return join "; ", @str;
+}
+
 #===================================
 sub _munge_elasticsearch_exception {
 #===================================
@@ -400,7 +420,7 @@ Search::Elasticsearch::Role::Cxn - Provides common functionality to HTTP Cxn imp
 
 =head1 VERSION
 
-version 5.01
+version 6.00
 
 =head1 DESCRIPTION
 
@@ -768,7 +788,7 @@ Clinton Gormley <drtech@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Elasticsearch BV.
+This software is Copyright (c) 2017 by Elasticsearch BV.
 
 This is free software, licensed under:
 
